alianator:
    - version: {{ alianator_version }}
pycord:
    - version: {{ pycord_version }}
python:
    - implementation: {{ python_implementation }}
    - version: {{ python_version }}
system-info:
    - name: {{ system_info.name }}
    - version: {{ system_info.version }}
    - architecture: {{ system_info.architecture }}